==> haskell-rsa-2.3.0-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.0
id: RSA-2.3.0-2cYy7RHfOLkI6zzjzEBdvH
key: RSA-2.3.0-2cYy7RHfOLkI6zzjzEBdvH
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: d39cd8952c21410584e6b62e52c8253f
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/RSA-2.3.0
hs-libraries: HSRSA-2.3.0-2cYy7RHfOLkI6zzjzEBdvH
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
    crypto-pubkey-types-0.4.3-DDhDciZOiDm4G4LZwuUaG3
    SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=80ac8ea08d0f7b8153da8b322f955d96
             crypto-pubkey-types-0.4.3-DDhDciZOiDm4G4LZwuUaG3=faaf7b9ef6354b1f10f3d339168a7f80
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=33923978692199f77b7db23661058675
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.3.0-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: RSA
version: 2.3.0
id: RSA-2.3.0-JM2tPSAsPmd4EDkauDt3Xc
key: RSA-2.3.0-JM2tPSAsPmd4EDkauDt3Xc
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>
author: Adam Wick <awick@galois.com>
stability: stable
synopsis: Implementation of RSA, using the padding schemes of PKCS#1 v2.1.
description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).
category: Cryptography, Codec
abi: 4f92796af4cd723b0523e911c91edf16
exposed: True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/RSA-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/RSA-2.3.0
hs-libraries: HSRSA-2.3.0-JM2tPSAsPmd4EDkauDt3Xc
depends:
    base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
    crypto-pubkey-types-0.4.3-G0Fbi9by1yaFCZHatDFnN3
    SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=80ac8ea08d0f7b8153da8b322f955d96
             crypto-pubkey-types-0.4.3-G0Fbi9by1yaFCZHatDFnN3=2378c7d92516a59aa269007e9e9efc6a
             SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73=33923978692199f77b7db23661058675
haddock-interfaces: /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html: /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
